pyMez.Code API documentation
Description: Code is the package designed as the top level of python code for pyMez. To reduce the burden of the...

Top

# pyMez.Code module

Code is the package designed as the top level of python code for pyMez. To reduce the burden of the importing of all subpackages/modules in pyMez internal code uses this as the starting place for the import. For example, in a module in the `DataHandlers subpackage, first you import the os and sys packages.

    import os
    import sys

then you add the code folder to the python path with

    sys.path.append(os.path.join(os.path.dirname( __file__ ), '..','..'))

or the second package above the module itself. By doing this you can now import another module from pyMez such as Code.Utils.Names without going through the pyMez `__init__.py` file that determines the full API. For helper functions that do not need all of pyMez this greatly speeds their standalone performance.

## Help

`pyMez`

Documentation Home | API Documentation Home | Examples | Index

Show source ≡

    """
     Code is  the package designed as the top level of python code for pyMez. To reduce the burden of the
     importing of all subpackages/modules in pyMez internal code uses this as the starting place for the import. For
     example, in a module in the <a href="./DataHandlers">`DataHandlers subpackage</a>,
     first you import the os and sys packages.

        #!python
        import os
        import sys

     then you add the code folder to the python path with

        #!python
        sys.path.append(os.path.join(os.path.dirname( __file__ ), '..','..'))

     or the second package above the module itself. By doing this you can now import another module from pyMez
     such as Code.Utils.Names without going through the pyMez `__init__.py` file that determines the full API.
     For helper
     functions that do not need all of pyMez this greatly speeds their standalone performance.

    Help
    ----
    <a href="../index.html">`pyMez`</a>

    <div>
    <a href="../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../index.html">API Documentation Home</a> |
    <a href="../../Examples/Html/Examples_Home.html">Examples</a> |
    <a href="../../Reference_Index.html">Index</a>
    </div>
    """

## Sub-modules

pyMez.Code.Analysis

The Analysis subpackage contains modules designed to change the content of objects created using a Model. For instance, a function that interpolates data from a table and returns a new table would live in Analysis/Interpolation.py . If a function or class is designed to only change the format of an ...

pyMez.Code.DataHandlers

The DataHandlers subpackage is designed to manipulate data, by allowing different data types to be opened, created, saved and updated. The subpackage is further divided into modules grouped by a common theme. Classes for data that are already on disk normally follows the following pattern: `instance...

pyMez.Code.FrontEnds

The FrontEnds Subpackage is designed to hold gui's a fuctioning webserver, etc that tie together all the functionality contained in pyMez. This subpackage is assumed to import all other subpackages in pyMez. Currently, there are 3 front ends targeted by pyMez: A wxPython set of windows like frontend...

pyMez.Code.InstrumentControl

InstrumentControl is a subpackage designed for communication between a computer and the outside world. It wraps NIVisa using the pyvisa module and integrates this wrapper with xml based instrument sheets found in `pyMez.Code.DataHandlers.XMLModels` examples of the xml can be found in pyMez/Instrumen...

pyMez.Code.Utils

Utils is a subpackage designed to provide utility functions and classes to the rest of pyMez or store one-off helper functions needed in daily development life. All other packages should if needed import this one.

## Help

`pyMez.Code`

<a href="../../....